@@ -3,6 +3,8 @@ package App::Parcimonie;
 use warnings;
 use strict;
 
+our $VERSION = '0.6'; # VERSION
+
 use App::Parcimonie::GnuPG::Interface;
 use Carp;
 use Clone qw{clone};
@@ -10,20 +12,14 @@ use Config::General qw/ParseConfig/;
 use Encode;
 use English qw/-no_match_vars/;
 use File::HomeDir;
-use GnuPG::Options;
-use IPC::System::Simple qw/capturex/;
 use List::MoreUtils qw/uniq/;
 use List::Util qw/shuffle/;
-use Path::Tiny;
+use Path::Class;
 use Try::Tiny;
-use version 0.77;
 
 use Exporter;
 our @ISA = qw(Exporter);
 
-use namespace::clean;
-
-
 =head1 NAME
 
 App::Parcimonie - tools for the parcimonie program
@@ -36,7 +32,7 @@ See bin/parcimonie :)
 
 =cut
 
-our @EXPORT = qw/pickRandomItems gpgPublicKeys gpgRecvKeys gpg_is_v21
+our @EXPORT = qw/pickRandomItems gpgPublicKeys gpgRecvKeys
                  checkGpgHasDefinedKeyserver averageLapseTime/;
 
 my $codeset;
@@ -71,17 +67,6 @@ sub pickRandomItems {
     return @randomized_pool[0..$n - 1];
 }
 
-=head2 gpg_is_v21()
-
-Detects the version of the gpg binary in the $PATH.
-Returns true iff. it is 2.1 or newer.
-
-=cut
-sub gpg_is_v21 {
-    version->parse(GnuPG::Interface->new()->version())
-        >= version->parse('2.1.0');
-}
-
 =head2 gpgPublicKeys()
 
 Returns the list of key fingerprints found in the public keyring.
@@ -95,14 +80,12 @@ sub gpgPublicKeys {
     my $gnupg_options = shift;
     my %gi_args       = @_;
 
-    my $gnupg = App::Parcimonie::GnuPG::Interface->new(
-        %gi_args,
-        options => GnuPG::Options->new(%{clone($gnupg_options)}),
-    );
+    my $gnupg = App::Parcimonie::GnuPG::Interface->new(%gi_args);
+    $gnupg->options->hash_init(%{ clone($gnupg_options) });
     $gnupg->get_public_keys_hex();
 }
 
-=head2 gpgRecvKeys( $keyids, $gnupg_options )
+=head2 gpgRecvKeys( @keyids )
 
 Imports the keys with the given key IDs from a keyserver.
 
@@ -117,10 +100,8 @@ sub gpgRecvKeys {
     my $gnupg_options = shift;
     my %gi_args       = @_;
 
-    my $gnupg = App::Parcimonie::GnuPG::Interface->new(
-        %gi_args,
-        options => GnuPG::Options->new(%{clone($gnupg_options)}),
-    );
+    my $gnupg = App::Parcimonie::GnuPG::Interface->new(%gi_args);
+    $gnupg->options->hash_init(%{ clone($gnupg_options) });
     my $err_h = IO::Handle->new();
     my $handles = GnuPG::Handles->new(stderr => $err_h);
     my $pid = $gnupg->recv_keys( handles => $handles, command_args => $keyids );
@@ -135,7 +116,7 @@ sub gpgRecvKeys {
     # Filter out lines such as:
     # 11:21:19 libtorsocks(27234): The symbol res_query() was not found...
     $std_err =~ s{
-                     ^                  # anchor at a line beginning
+                     ^			# anchor at a line beginning
                      [[:digit:]]{2}
                      [:]
                      [[:digit:]]{2}     # time such as 11:21:19
@@ -167,38 +148,18 @@ sub gpgRecvKeys {
 
 Throws an exception if no keyserver is defined in GnuPG configuration.
 
-When using GnuPG 2.x, a keyserver can be defined either in dirmngr's
-configuration or in good old gpg.conf, so we check both.
-
 =cut
 
 sub checkGpgHasDefinedKeyserver {
-    my $gnupg_options = shift;
-    my $arg_ref       = shift;
-    my $gnupg_homedir = $gnupg_options->{homedir};
-
-    my @homedir_args = defined $gnupg_homedir
-        ? ('--homedir', $gnupg_homedir)
-        : ();
-    my @output = capturex(
-        'gpg-connect-agent', @homedir_args,
-        qw{--dirmngr keyserver /bye}
-    );
-    my $res = pop @output;
-    $res eq "OK\n" || croak "Agent replied: $res";
-    if (@output) {
-        my $last_keyserver = pop @output;
-        if ($last_keyserver =~ m{\A [S] \s+ KEYSERVER \s+}xms) {
-            return;
-        }
-    }
+    my $arg_ref = shift;
+    my $gnupg_homedir = $arg_ref->{homedir};
 
     my $gpgconf;
     if (defined $gnupg_homedir) {
-        $gpgconf = path($gnupg_homedir, 'gpg.conf');
+        $gpgconf = file($gnupg_homedir, 'gpg.conf');
     }
     else {
-        $gpgconf = path(File::HomeDir->my_home, '.gnupg', 'gpg.conf');
+        $gpgconf = file(File::HomeDir->my_home, '.gnupg', 'gpg.conf');
     }
 
     -f $gpgconf
