@@ -7,15 +7,19 @@ App::Parcimonie::Applet - systray applet object monitoring parcimonie's activiti
 =cut
 
 package App::Parcimonie::Applet;
-use Moo;
-use MooX::late;
+use Any::Moose;
+with 'App::Parcimonie::Role::HasEncoding';
+
+our $VERSION = '0.6'; # VERSION
 
 use 5.10.0;
+use namespace::autoclean;
 
 use Encode;
 
 use Glib qw{TRUE FALSE};
-use Gtk3 qw{-init};
+use Gtk2 qw{-init};
+use Gtk2::Gdk::Keysyms;
 
 use Net::DBus;
 use Net::DBus::GLib;
@@ -25,14 +29,8 @@ use POSIX;
 setlocale(LC_MESSAGES, "");
 textdomain("parcimonie-applet");
 
-use Time::Duration;
 use Try::Tiny;
 
-use namespace::clean;
-
-with 'App::Parcimonie::Role::HasEncoding';
-use MooX::StrictConstructor;
-
 
 =head1 ATTRIBUTES
 
@@ -61,19 +59,19 @@ has 'dbus_object' => (
 );
 
 has 'statusicon'  => (
-    isa        => 'Gtk3::StatusIcon',
+    isa        => 'Gtk2::StatusIcon',
     is         => 'rw',
     lazy_build => 1,
  );
 
 has 'monitorwin'  => (
-    isa        => 'Gtk3::Window',
+    isa        => 'Gtk2::Window',
     is         => 'rw',
     lazy_build => 1,
 );
 
 has 'logbuffer'   => (
-    isa        => 'Gtk3::TextBuffer',
+    isa        => 'Gtk2::TextBuffer',
     is         => 'rw',
     lazy_build => 1,
 );
@@ -89,13 +87,13 @@ sub BUILD {
 
 sub _build_monitorwin {
     my $self = shift;
-    my $win = Gtk3::Window->new('toplevel');
+    my $win = Gtk2::Window->new('toplevel');
     $win->set_title($self->encoding->decode(gettext('parcimonie log viewer')));
     $win->set_keep_above(1);
     $win->set_position('center');
     $win->signal_connect('delete_event' => sub { $win->hide; 1; });
 
-    my $textview = Gtk3::TextView->new_with_buffer($self->logbuffer);
+    my $textview = Gtk2::TextView->new_with_buffer($self->logbuffer);
     $textview->set_editable(FALSE);
     $textview->set_cursor_visible(FALSE);
     $textview->set_wrap_mode('word');
@@ -104,7 +102,7 @@ sub _build_monitorwin {
     $text_desc->set_family('Monospace');
     $textview->modify_font($text_desc);
 
-    my $scrolled_win = Gtk3::ScrolledWindow->new;
+    my $scrolled_win = Gtk2::ScrolledWindow->new;
     $scrolled_win->set_policy('automatic', 'automatic');
     $scrolled_win->add($textview);
 
@@ -115,7 +113,7 @@ sub _build_monitorwin {
     $win->signal_connect('key-press-event' => sub {
         my $twin = shift;
         my $event = shift;
-        $win->hide if $event->key->{keyval} == Gtk3::Gdk::keyval_from_name('Escape');
+        $win->hide if $event->keyval == $Gtk2::Gdk::Keysyms{Escape};
     });
 
     return $win;
@@ -123,23 +121,23 @@ sub _build_monitorwin {
 
 sub _build_logbuffer {
     my $self = shift;
-    Gtk3::TextBuffer->new;
+    Gtk2::TextBuffer->new;
 }
 
 sub _build_statusicon {
     my $self = shift;
-    my $icon = Gtk3::StatusIcon->new;
+    my $icon = Gtk2::StatusIcon->new;
 
     $icon->set_visible(FALSE);
     $icon->set_from_stock('gtk-media-pause');
 
-    my $menu = Gtk3::Menu->new;
-    my $mlog = Gtk3::MenuItem->new_with_mnemonic($self->encoding->decode(gettext('View log')));
+    my $menu = Gtk2::Menu->new;
+    my $mlog = Gtk2::MenuItem->new($self->encoding->decode(gettext('View log')));
     $mlog->signal_connect('activate' => sub { $self->monitorwin->show_all });
-    my $mexit = Gtk3::MenuItem->new_with_mnemonic($self->encoding->decode(gettext('Exit')));
-    $mexit->signal_connect('activate' => sub { Gtk3->main_quit; });
-    my $mabout = Gtk3::MenuItem->new_with_mnemonic($self->encoding->decode(gettext('About')));
-    $mabout->signal_connect('activate' => sub { Gtk3->show_about_dialog(
+    my $mexit = Gtk2::MenuItem->new($self->encoding->decode(gettext('Exit')));
+    $mexit->signal_connect('activate' => sub { Gtk2->main_quit; });
+    my $mabout = Gtk2::MenuItem->new($self->encoding->decode(gettext('About')));
+    $mabout->signal_connect('activate' => sub { Gtk2->show_about_dialog(
         $self->monitorwin,
         'program-name' => 'Parcimonie applet',
         'license'      => q{This program is free software; you can redistribute it and/or modify it under the terms of either:
@@ -152,14 +150,14 @@ b) the "Artistic License" which comes with Perl.
         'website'      => 'https://gaffer.ptitcanardnoir.org/intrigeri/code/parcimonie/',
     )});
     $menu->append($mlog);
-    $menu->append(Gtk3::SeparatorMenuItem->new);
+    $menu->append(Gtk2::SeparatorMenuItem->new);
     $menu->append($mexit);
-    $menu->append(Gtk3::SeparatorMenuItem->new);
+    $menu->append(Gtk2::SeparatorMenuItem->new);
     $menu->append($mabout);
 
     $icon->signal_connect('popup-menu', sub {
         my ($ticon, $button, $time) = @_;
-        my ($x, $y, $push) = Gtk3::StatusIcon::position_menu($menu, $ticon);
+        my ($x, $y, $push) = Gtk2::StatusIcon::position_menu($menu, $ticon);
         $menu->show_all;
         $menu->popup(undef, undef, sub {($x, $y,$push)}, undef, $button, $time);
     });
@@ -168,8 +166,8 @@ b) the "Artistic License" which comes with Perl.
         my $ticon = shift;
         my $event = shift;
         return unless $event->button == 1;
-        if ($self->monitorwin->get_visible) {
-            $self->monitorwin->hide;
+        if ($self->monitorwin->visible) {
+            $self->monitorwin->hide_all;
         }
         else {
             $self->monitorwin->show_all;
@@ -211,8 +209,8 @@ sub run {
         unless $self->has_dbus_object;
     $self->debug("Connected to the daemon's D-Bus service.");
     $self->init_dbus_watcher;
-    $self->debug("Entering main Gtk3 loop.");
-    Gtk3->main;
+    $self->debug("Entering main Gtk2 loop.");
+    Gtk2->main;
 }
 
 sub build_ui {
@@ -245,16 +243,13 @@ sub init_dbus_watcher {
     $self->dbus_object->connect_to_signal("FetchEnd", sub {
         $self->signal_fetch_end_cb(@_);
     });
-    $self->dbus_object->connect_to_signal("Sleeping", sub {
-        $self->signal_sleeping_cb(@_);
-    });
 }
 
 sub append_mesg {
     my $self = shift;
     my $mesg = shift;
     my $buffer = $self->logbuffer;
-    $buffer->insert($buffer->get_end_iter, $mesg . "\n", -1);
+    $buffer->insert($buffer->get_end_iter, $mesg . "\n");
 }
 
 sub signal_fetch_begin_cb {
@@ -267,7 +262,7 @@ sub signal_fetch_begin_cb {
     );
     $self->debug($mesg);
     $self->statusicon->set_from_stock('gtk-refresh');
-    $self->statusicon->set_tooltip_text($mesg);
+    $self->statusicon->set_tooltip($mesg);
     $self->append_mesg($mesg);
     $self->statusicon->set_visible(TRUE);
 }
@@ -298,30 +293,25 @@ sub signal_fetch_end_cb {
 
     $self->debug($mesg);
     $self->statusicon->set_from_stock($new_pixmap);
-    $self->statusicon->set_tooltip_text($mesg);
+    $self->statusicon->set_tooltip($mesg);
     $self->append_mesg($mesg);
     $self->statusicon->set_visible(TRUE);
     Glib::Timeout->add(
         $self->icon_display_time * 1000,
-        sub { 1 }
+        sub { $self->now_resting; }
     );
 }
 
-sub signal_sleeping_cb {
-    my $self     = shift;
-    my $duration = shift;
-
-    # TRANSLATORS: sleeping time
-    my $mesg = $self->encoding->decode(
-        sprintf(gettext('Sleeping for %s...'), duration($duration))
-    );
-    $self->debug($mesg);
+sub now_resting {
+    my $self = shift;
     $self->statusicon->set_from_stock('gtk-media-pause');
-    $self->statusicon->set_tooltip_text($mesg);
-    $self->append_mesg($mesg);
+    $self->statusicon->set_tooltip($self->encoding->decode(
+        gettext('Having a rest.')
+    ));
     $self->statusicon->set_visible(TRUE);
+    # return false so that the Glib::Timeout stops looping
+    return;
 }
 
-no Moo;
-
+no Any::Moose;
 1;
