@@ -9,14 +9,14 @@ package App::Parcimonie::DBus::Object;
 use strict;
 use warnings;
 
+our $VERSION = '0.6'; # VERSION
+
 # We're going to be a DBus object
 use base qw{Net::DBus::Object};
 
 # Specify the main interface provided by our object
 use Net::DBus::Exporter qw{org.parcimonie.daemon};
 
-use namespace::clean;
-
 sub new {
     my $class = shift;
     my $service = shift;
@@ -30,6 +30,3 @@ dbus_signal("FetchBegin", ["string"]);
 
 # args: keyid, success, error message
 dbus_signal("FetchEnd", ["string", "bool", "string"]);
-
-# args: duration
-dbus_signal("Sleeping", ["uint32"]);
