@@ -9,19 +9,14 @@ Have a look to App::Parcimonie::Daemon for a full-blown real life usage example.
 =cut
 
 package App::Parcimonie::GnuPG::Interface;
+use Any::Moose;
+extends 'GnuPG::Interface';
 
-use Moo;
-use MooX::late;
+our $VERSION = '0.6'; # VERSION
+
+use namespace::autoclean;
 use Carp;
 use File::Which qw{which};
-use IPC::System::Simple qw{system systemx};
-
-use namespace::clean;
-
-# This child class cannot use MooX::StrictConstructor:
-# see "Inheritance" section in its doc for details.
-
-extends 'GnuPG::Interface';
 
 has 'already_torified' => (
     isa      => 'Bool',
@@ -33,17 +28,10 @@ has 'already_torified' => (
 after 'BUILD' => sub {
     my $self = shift;
     unless ($self->already_torified) {
-        my $gnupg_homedir = defined $self->options->homedir()
-            ? $self->options->homedir()
-            : '';
-        system(
-            q{echo 'use-tor:0:1' | } .
-            "GNUPGHOME='$gnupg_homedir' gpgconf --change-options dirmngr " .
-            ">/dev/null"
-        );
-        # Passing --runtime to the previous command does not work,
-        # so we have to:
-        system("GNUPGHOME='$gnupg_homedir' gpgconf --reload dirmngr");
+        foreach my $prog (qw{torsocks parcimonie-torified-gpg}) {
+            defined which($prog) or croak "$prog not found in \$PATH";
+        }
+        $self->call('parcimonie-torified-gpg');
     }
 };
 
@@ -106,5 +94,5 @@ sub get_public_keys_hex {
 
 }
 
-no Moo;
+no Any::Moose;
 1; # End of App::Parcimonie::GnuPG::Interface
