@@ -4,27 +4,30 @@ App::Parcimonie::Role::HasEncoding - role to provide an Encode::Encoding objet f
 
 =head1 SYNOPSIS
 
-    use Moo;
-    with 'App::Parcimonie::Role::HasEncoding';
-    sub foo { $self->encoding->decode("bla") }
+    use MooseX::Declare;
+    class App::Parcimonie::Daemon with App::Parcimonie::Role::HasEncoding {
+        method foo (Str $bytes) { $self->encoding-> }
+    }
 
     See App::Parcimonie::Daemon for a real-life usage example.
 
 =cut
 
 package App::Parcimonie::Role::HasEncoding;
+use Any::Moose 'Role';
 
-use Encode qw{find_encoding};
-
-use Moo::Role; # Moo::Role exports all methods declared after it's "use"'d
-use MooX::late;
+our $VERSION = '0.6'; # VERSION
 
+use namespace::autoclean;
 with 'App::Parcimonie::Role::HasCodeset';
+use Encode qw{find_encoding};
+use Any::Moose '::Util::TypeConstraints';
 
-use namespace::clean;
+class_type('Encode::Encoding');
+class_type('Encode::XS');
 
 has 'encoding' => (
-    isa        => 'Encode::Encoding|Encode::XS',
+    isa        => 'Encode::Encoding | Encode::XS',
     is         => 'ro',
     lazy_build => 1,
 );
@@ -34,5 +37,5 @@ sub _build_encoding {
     find_encoding($self->codeset);
 }
 
-no Moo::Role;
+no Any::Moose 'Role';
 1; # End of App::Parcimonie::Role::HasEncoding
